# Available indicators in the ODA data package


## Financing indicators (from DAC1)

|         Indicator name          |                                                                                                                         Description                                                                                                                         |                                                 How we calculate it                                                  |
|:-------------------------------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|:--------------------------------------------------------------------------------------------------------------------:|
|       total_oda_flow_net        |                                                                                 Total ODA disbursements, in net terms. This was the official definition of ODA until 2017.                                                                                  |                       We filter table DAC1 for "aid type code" `1010` and "flows code" `1040`                        |
|          total_oda_ge           |                                                                              Total ODA "effort", in grant equivalent terms. This is the official definition of ODA since 2018.                                                                              |                       We filter table DAC1 for "aid type code" `11010` and "flows code" `1060`                       |
|  total_oda_official_definition  | This is not an official ODA indicator. Instead, we add it for convenience as it combines data from the _total_oda_flow_net_ indicator and _total_oda_ge_ in order to create a continuous timeseries which always displays the "official" definition of ODA. | We combine "total_oda_flow_net" for years before 2018 and "total_oda_ge" for years from 2018 into a single indicator |
|  total_oda_bilateral_flow_net   |                                                                       Total bilateral ODA, according to the definition used by the OECD DAC in table 1a. Expressed in net flow terms.                                                                       |                       We filter table DAC1 for "aid type code" `1015` and "flows_code" `1140`                        |
|     total_oda_bilateral_ge      |                                                                   Total bilateral ODA, according to the definition used by the OECD DAC in table 1a. Expressed in grant equivalent terms                                                                    |                       We filter table DAC1 for "aid type code" `11015` and "flows code" `1160`                       |
| total_oda_multilateral_flow_net |                                                                      Total multilateral ODA, according to the definition used by the OECD DAC in table 1a. Expressed in net flow terms                                                                      |                       We filter table DAC1 for "aid type code" `2000` and "flows_code" `1140`                        |
|    total_oda_multilateral_ge    |                                                                Total multilateral ODA, according to the definition used by the OECD DAC in table 1a. Expressed in net grant equivalent terms                                                                |                       We filter table DAC1 for "aid type code" `12000` and "flows_code" `1160`                       |
|      total_oda_flow_gross       |                                                                                                    Total ODA disbursements in gross disbursements terms.                                                                                                    |                       We filter table DAC1 for "aid type code" `1010` and "flows code" `1120`                        |
|   total_oda_flow_commitments    |                                                                                                                    Total ODA commitments                                                                                                                    |                       We filter table DAC1 for "aid type code" `1010` and "flows code" `1150`                        |
|      total_oda_grants_flow      |                                                                       Total ODA "grants", according to the definition used by the OECD DAC in table 1a. Expressed in (net) flow terms                                                                       |                       We filter table DAC1 for "aid type code" `1010` and "flows code" `1121`                        |
|       total_oda_grants_ge       |                                       Total ODA "grants", according to the definition used by the OECD DAC in table 1a. Expressed in grant equivalent terms (though grant equivalents for grants are equal to flows)                                        |                We filter table DAC1 for "aid type codes" `11016` and `12100` and "flows_code" `1160`                 |
|    total_oda_non_grants_flow    |                                                                         Total ODA "non grants" according to the definition used by the OECD DAC in table 1a. Expressed as net flows                                                                         |                       We filter table DAC1 for "aid type code" `1010` and "flows code" `1122`                        |
|     total_oda_non_grants_ge     |                                                  Total ODA "non grants", expressed in grant equivalent terms. Note that not all flows (like PSI) have grant equivalent terms, even if they are not grants.                                                  |         We filter table DAC1 for "aid type codes' `11017`, `12110`, `11026`, `11018` and "flows code" `1160`         |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |
|                                 |                                                                                                                                                                                                                                                             |                                                                                                                      |


## Indicators from table DAC2a (donors and recipients)
|          Indicator name          | Description | How we calculate it |
|:--------------------------------:|:-----------:|:-------------------:|
| recipient_imputed_multi_flow_net |             |                     |
|   recipient_bilateral_flow_net   |             |                     |
|  recipient_bilateral_flow_gross  |             |                     |
|    recipient_loans_flow_gross    |             |                     |
|     recipient_loans_flow_net     |             |                     |
|                                  |             |                     |
|                                  |             |                     |
